@@ -22,6 +22,17 @@ BEGIN {
         || CLASS->error("You don't have YAML installed");
 }
 
+eval "require YAML::XS";
+our $HAS_YAML_XS = $@ ? 0 : 1;
+
+eval "require YAML";
+our $HAS_YAML = $@ ? 0 : 1;
+our $MODULE =
+    $HAS_YAML    ? 'YAML::XS' :
+    $HAS_YAML    ? 'YAML'     :
+    die "No YAML implementation installed\n";
+
+
 sub encode {
     my $self = shift;
     YAML::Dump(shift);
@@ -90,11 +101,11 @@ all the decoding work, i.e. the C<Load()> subroutine in L<YAML>.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
+Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
+Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
 
 =head1 SEE ALSO
 
