@@ -18,7 +18,7 @@ use Badger::Factory::Class
     version   => 0.01,
     debug     => 0,
     item      => 'codec',
-    path      => 'Badger::Codec BadgerX::Codec',
+    path      => 'Badger(X)::Codec',
     import    => 'class CLASS',
     constants => 'HASH ARRAY DELIMITER PKG',
     constant  => {
@@ -38,6 +38,8 @@ our $CODECS     = {
     url      => 'Badger::Codec::URL',
     yaml     => 'Badger::Codec::YAML',
     json     => 'Badger::Codec::JSON',
+    html     => 'Badger::Codec::HTML',
+    tt       => 'Badger::Codec::TT',
     map {
         my $name = $_; $name =~ s/\W//g;
         $_ => [ENCODING, ENCODING.PKG.$name],
@@ -608,11 +610,14 @@ mappings to bypass the automagical name grokking mechanism.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
+Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
+Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
+
+This module is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
 
