@@ -17,7 +17,7 @@ use File::Spec;
 use Badger::Class
     version      => 0.01,
     debug        => 0,
-    base         => 'Badger::Base Badger::Exporter',
+    base         => 'Badger::Filesystem::Base Badger::Exporter',
     import       => 'class',
     constants    => 'HASH ARRAY TRUE',
     get_methods  => 'path name volume directory',
@@ -31,7 +31,7 @@ use Badger::Class
         STAT_PATH    => 17,         # offset in extended stat fields
     },
     exports      => {
-        tags     => { fields => '@VDN_FIELDS @VD_FIELDS @STAT_FIELDS' },
+        tags     => { fields => '@STAT_FIELDS' },
     },
     messages     => {
         no_exist => '%s does not exist: %s',
@@ -40,33 +40,72 @@ use Badger::Class
         missing  => 'No %s specified',
     };
 
+use Badger::Timestamp;
 use Badger::Filesystem;
 use Badger::Filesystem::Directory;
 
-our $FILESYSTEM  = 'Badger::Filesystem';
-our @VDN_FIELDS  = qw( volume directory name );
-our @VD_FIELDS   = qw( volume directory );
-our @STAT_FIELDS = qw( device inode mode links user group device_type 
-                       size accessed modified created block_size blocks
-                       readable writeable executable owner );
 
-# generate methods to access stat fields
+our $FILESYSTEM  = 'Badger::Filesystem';
+our $TIMESTAMP   = 'Badger::Timestamp';
+our $MATCH_EXT   = qr/\.([^\.]+)$/;       # TODO: is this filesystem-specific?
+our @VDN_FIELDS  = @Badger::Filesystem::Base::VDN_FIELDS;
+our @STAT_FIELDS = qw( device inode mode links user group device_type 
+                       size atime mtime ctime block_size blocks
+                       readable writeable executable owner );
+our $STAT_FIELD  = { 
+    # In here we'll store the map from stat field name to number
+    #   device => 0,
+    #   inode  => 1, 
+    #   ...etc...
+};
+
+our $TS_FIELD = {
+    # On the left we have the timestamp methods we want to generate as 
+    # wrappers around the stat fields listed on the right.
+    created  => 'ctime',
+    accessed => 'atime',
+    modified => 'mtime',
+};
+
+# generate methods to access stat fields: mode(), atime(), ctime(), etc.
 my $n = 0;
+
 class->methods(
     map { 
-        my $m = $n++;       # new lexical variable to bind in closure
-        $_ => sub { $_[0]->stats->[$m] }
-    } @STAT_FIELDS
+        my $m = $n++;                       # new lexical variable for closure
+        $STAT_FIELD->{ $_ } = $m;           # fill in $STAT_FIELD entry
+        $_ => sub { $_[0]->stats->[$m] }    # generate subroutine
+    } 
+    @STAT_FIELDS
 );
 
+# generate accessed(), created() and modified() methods which return
+# Badger::Timestamp objects for the atime, ctime and mtime stat values
+
+class->methods(
+    map { 
+        my $method = $_;                    # new lexical variable for closure
+        my $stat   = $TS_FIELD->{ $_ };
+        my $statno = $STAT_FIELD->{ $stat };
+        $method => sub { 
+            return $_[0]->{ $method } 
+                ||= $TIMESTAMP->new( $_[0]->stats->[$statno] )
+        }
+    } 
+    keys %$TS_FIELD
+);
+
+
 # define some aliases
 *is_dir    = \&is_directory;
 *dir       = \&directory;
 *vol       = \&volume;     # goes up to 11
 *ext       = \&extension;  
+*base_name = \&basename;
 *up        = \&parent;
 *meta      = \&metadata;
 *canonical = \&absolute;
+*perms     = \&permissions;
 
 
 sub new {
@@ -146,8 +185,8 @@ sub definitive {
 sub collapse {
     my $self = shift->absolute;
     my $fs   = $self->filesystem;
-    $self->{ directory } = $fs->collapse_directory($self->{ directory });
-    $self->{ path      } = $fs->join_path(@$self{@VDN_FIELDS});
+    $self->{ directory } = $fs->collapse_directory( $self->{ directory } );
+    $self->{ path      } = $fs->join_path( @$self{ @VDN_FIELDS } );
     return $self;
 }
 
@@ -223,8 +262,6 @@ sub path_up {
 
 sub exists {
     shift->stat;
-#    my $self = shift;
- #   return $self->filesystem->stat_path($self->{ path })
 }
 
 sub must_exist {
@@ -232,8 +269,9 @@ sub must_exist {
 
     unless ($self->exists) {
         if (@_ && $_[0]) {
+            my $flag = shift;
             # true flag indicates we should attempt to create it
-            $self->create;
+            $self->create(@_);      # pass any other args, like dir file permission
         }
         else {
             return $self->error_msg( no_exist => $self->type, $self->{ path } );
@@ -268,10 +306,27 @@ sub stats {
         :  $stats;
 }
 
+sub permissions {
+    shift->mode & 0777;
+}
+    
+sub chmod {
+    my $self = shift;
+    $self->filesystem->chmod_path($self->{ path }, @_);
+    return $self;
+}
+
+sub basename {
+    my $self = shift;
+    my $name = $self->name;
+    $name = $self->{ path } unless defined $name;
+    $name =~ s/$MATCH_EXT//g;
+    return $name;
+}
+
 sub extension {
     my $self = shift;
-    # TODO: is this filesystem specific?
-    return $self->{ path } =~ /\.([^\.]+)$/
+    return $self->{ path } =~ $MATCH_EXT
         ? $1
         : '';
 }
@@ -355,6 +410,8 @@ Badger::Filesystem::Path - generic fileystem path object
     $path->path;                    # current path
     $path->base;                    # parent directory or path itself
     $path->parent;                  # directory object for base
+    $path->extension                # filename .XXX extension
+    $path->basename                 # filename without .XXX extension
     $path->is_absolute;             # path is absolute
     $path->is_relative;             # path is relative
     $path->exists;                  # returns true/false
@@ -553,7 +610,7 @@ filesystem).
     my $path = Path('/foo/bar/../baz')->collapse;
     print $path;   # /foo/baz
 
-See the L<collapse_dir()|Badger::Filesystem/collapse()> method in 
+See the L<collapse_dir()|Badger::Filesystem/collapse_dir()> method in 
 L<Badger::Filesystem> for further information.
 
 =head2 above($child)
@@ -626,10 +683,6 @@ root directory ('/') will be returned.  A relative path with only one item
 (e.g. 'foo') is assumed to be relative to the current working directory
 which will be returned (e.g. '/path/to/current/dir').
 
-=head2 extension() / ext()
-
-Returns any file extension portion following the final C<.> in the path.
-
 =head2 exists()
 
 Returns true if the path exists in the filesystem (e.g. as a file, directory,
@@ -668,6 +721,12 @@ L<Badger::Filesystem::Directory> subclasses.
     $dir->create;                           # OK
     $file->create;                          # OK
 
+=head2 chmod($perms)
+
+This method changes the file permissions on a file or directory.
+
+    $file->chmod(0775);
+
 =head2 stat()
 
 Performs a filesystem C<stat> on the path and returns a list (in list
@@ -691,9 +750,9 @@ methods, also listed in the table.
       5     group()         numeric group ID of file’s owner
       6     device_type()   the device identifier (special files only)
       7     size()          total size of file, in bytes
-      8     accessed()      last access time in seconds since the epoch
-      9     modified()      last modify time in seconds since the epoch
-     10     created()       inode change time in seconds since the epoch (*)
+      8     atime()         last access time in seconds since the epoch
+      9     mtime()         last modify time in seconds since the epoch
+     10     ctime()         inode change time in seconds since the epoch (*)
      11     block_size()    preferred block size for file system I/O
      12     blocks()        actual number of blocks allocated
 
@@ -713,83 +772,115 @@ making repeated filesystem calls.
     @list = $path->stats;                   # list context
     $list = $path->stats;                   # scalar context
 
-=head2 device
+=head2 device()
 
 Returns the device number for the file.  See L<stat()>.
 
-=head2 inode 
+=head2 inode()
 
 Returns the inode number for the file.  See L<stat()>.
 
-=head2 mode
+=head2 mode()
 
-Returns the file mode for the file.  See L<stat()>.
+Returns the file mode for the file.  Note that this contains both the 
+file type and permissions.  See L<stat()>.
 
-=head2 links
+=head2 permissions() / perms()
+
+Returns the file permissions.  This is equivalent to 
+C<< $file->mode & 0777 >>.
+
+=head2 links()
 
 Returns the number of hard links to the file.  See L<stat()>.
 
-=head2 user
+=head2 user()
 
 Returns the numeric user ID of the file's owner.  See L<stat()>.
 
-=head2 group
+=head2 group()
 
 Returns the numeric group ID of the file's group.  See L<stat()>.
 
-=head2 device_type 
+=head2 device_type()
 
 Returns the device identifier (for special files only).  See L<stat()>.
 
-=head2 size
+=head2 size()
 
 Returns the total size of the file in bytes.  See L<stat()>.
 
-=head2 accessed
+=head2 atime()
 
 Returns the time (in seconds since the epoch) that the file was last accessed.
 See L<stat()>.
 
-=head2 modified
+=head2 accessed()
+
+Returns a L<Badger::Timestamp> object for the L<atime()> value.  This object
+will auto-stringify to produce an ISO-8601 formatted date.  You can also 
+call various methods to access different parts of the time and/or date.
+
+    print $file->accessed;              # 2009/04/20 16:25:00
+    print $file->accessed->date;        # 2009/04/20
+    print $file->accessed->year;        # 2009
+
+=head2 mtime()
 
 Returns the time (in seconds since the epoch) that the file was last modified.
 See L<stat()>.
 
-=head2 created
+=head2 modified()
+
+Returns a L<Badger::Timestamp> object for the L<mtime()> value.
+
+    print $file->modified;              # 2009/04/20 16:25:00
+    print $file->modified->time;        # 16:25:0
+    print $file->modified->hour;        # 16
+
+=head2 ctime()
 
 Returns the time (in seconds since the epoch) that the file was created. See
 L<stat()>.
 
-=head2 block_size
+=head2 created()
+
+Returns a L<Badger::Timestamp> object for the L<ctime()> value.
+
+    print $file->created;               # 2009/04/20 16:25:00
+    print $file->created->date;         # 2009/04/20
+    print $file->created->time;         # 16:25:00
+
+=head2 block_size()
 
 Returns the preferred block size for file system I/O on the file. See
 L<stat()>.
 
-=head2 blocks 
+=head2 blocks()
 
 Returns the actual number of blocks allocated to the file. See L<stat()>.
 
-=head2 readable
+=head2 readable()
 
 Returns a true value if the file is readable by the current user (i.e. the
 owner of the current process), false if not.  See L<stat()>.
 
-=head2 writeable
+=head2 writeable()
 
 Returns a true value if the file is writeable by the current user (i.e. the
 owner of the current process), false if not.  See L<stat()>.
 
-=head2 executable
+=head2 executable()
 
 Returns a true value if the file is executable by the current user (i.e. the
 owner of the current process), false if not.  See L<stat()>.
 
-=head2 owner                       
+=head2 owner()                
 
 Returns a true value if the file is owned by the current user (i.e. the
 owner of the current process), false if not.  See L<stat()>.
 
-=head2 filesystem
+=head2 filesystem()
 
 Returns a reference to a L<Badger::Filesystem> object, or the name of the
 filesystem class (e.g. L<Badger::Filesystem> or a subclass) that created
@@ -917,13 +1008,38 @@ C<Badger::Filesystem::Path> base class.
 Returns the file name portion of a path. This method does nothing in the
 C<Badger::Filesystem::Path> base class.
 
+=head2 extension() / ext()
+
+Returns any file extension portion following the final C<.> in the path.
+This works in the C<Badger::Filesystem::Path> base class by looking at the
+full path.
+
+    print Path('/foo/bar.txt')->extension;      # txt
+
+=head2 basename() / base_name()
+
+Returns the filename I<without> the file extension following the final 
+C<.> in the path.  This works (for some definition of "works") in the 
+C<Badger::Filesystem::Path> base class by looking at the path L<name()>,
+if defined, or the full C<path> if not.  Note that this will produce 
+unexpected results in some cases due to the fact that the base class 
+does not define a value for L<name()>.  e.g.
+
+    print Path('/foo/bar.txt')->basename;       # /foo/bar
+
+However, in most cases you would be using this through a
+L<Badger::Filesystem::File> subclass which will product the correct 
+results.
+
+    print File('/foo/bar.txt')->basename;       # bar
+
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
+Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
+Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
 
 =head1 ACKNOWLEDGEMENTS
 
